[![Documentation Status](https://readthedocs.org/projects/sle-prjmgr-tools/badge/?version=latest)](https://sle-prjmgr-tools.readthedocs.io/en/latest/?badge=latest)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


# sle-prjmgr-tools

This is a repository containing shared release management tools for SUSE. Tools are expected to be version agnostic,
release or version specific tools should be clearly documented.

## How to install & use

The preferred way are the RPMs.

You may install the tool via either:

- `zypper in sle-prjmgr-tools`
- `pip install sle-prjmgr-tools`
- `pip install git+https://github.com/openSUSE/sle-prjmgr-tools.git`
- or you install it from the locally built RPMs or via pip.

## Tool overview

For an overview see `sle-prjmgr-tools -h` or `sle-prjmgr-tools <tool_name> -h`.

## Archive of the old code

This repository has its root (before open-sourcing it) in the internal SUSE Gitlab. If you have access then you may
visit the history [here](https://gitlab.suse.de/sle-prjmgr/release-management-tools).
